@@ -1,8 +1,13 @@
-import logging
 import pytest
 import unittest
 
-from asf_search import ASFProduct, ASFSearchResults, ASFSearchOptions, ASFSession, FileDownloadType
+from asf_search import (
+    ASFProduct,
+    ASFSearchResults,
+    ASFSearchOptions,
+    ASFSession,
+    FileDownloadType,
+)
 from unittest.mock import patch
 from shapely.geometry import shape
 from shapely.ops import orient
@@ -11,6 +16,7 @@ import requests
 
 from asf_search.search.search_generator import as_ASFProduct
 
+
 def run_test_ASFProduct(product_json):
     if product_json is None:
         product = ASFProduct()
@@ -25,21 +31,22 @@ def run_test_ASFProduct(product_json):
     product = as_ASFProduct(product_json, ASFSession())
 
     geojson = product.geojson()
-    
+
     if geojson['geometry']['coordinates'] is not None:
         expected_shape = orient(shape(product_json['geometry']))
-        output_shape = orient(shape(geojson['geometry'])) 
-        assert(output_shape.equals(expected_shape))
+        output_shape = orient(shape(geojson['geometry']))
+        assert output_shape.equals(expected_shape)
     elif product.meta != {}:
         assert product.properties == product_json['properties']
         assert product.geometry == product_json['geometry']
 
-    assert(product.umm == product_json["umm"])
-    assert(product.meta == product_json["meta"])
+    assert product.umm == product_json['umm']
+    assert product.meta == product_json['meta']
+
 
 def run_test_stack(reference, pre_processed_stack, processed_stack):
     product = as_ASFProduct(reference, ASFSession())
-    
+
     with patch('asf_search.baseline_search.search') as search_mock:
         temp = ASFSearchResults([as_ASFProduct(prod, ASFSession()) for prod in pre_processed_stack])
         for idx, prod in enumerate(temp):
@@ -47,18 +54,29 @@ def run_test_stack(reference, pre_processed_stack, processed_stack):
         search_mock.return_value = temp
         stack = product.stack()
 
-
         stack = [
-            product for product in stack if product.properties['temporalBaseline'] != None and product.properties['perpendicularBaseline'] != None
-            ]
+            product
+            for product in stack
+            if product.properties['temporalBaseline'] is not None
+            and product.properties['perpendicularBaseline'] is not None
+        ]
+
+        for idx, secondary in enumerate(stack):
+            if idx > 0:
+                assert (
+                    secondary.properties['temporalBaseline']
+                    >= stack[idx - 1].properties['temporalBaseline']
+                )
+
+            assert (
+                secondary.properties['temporalBaseline']
+                == processed_stack[idx]['properties']['temporalBaseline']
+            )
+            assert (
+                secondary.properties['perpendicularBaseline']
+                == processed_stack[idx]['properties']['perpendicularBaseline']
+            )
 
-        for(idx, secondary) in enumerate(stack):
-            
-            if(idx > 0):
-                assert(secondary.properties['temporalBaseline'] >= stack[idx - 1].properties['temporalBaseline'])
-            
-            assert(secondary.properties['temporalBaseline'] == processed_stack[idx]['properties']['temporalBaseline'])
-            assert(secondary.properties['perpendicularBaseline'] == processed_stack[idx]['properties']['perpendicularBaseline'])
 
 def run_test_product_get_stack_options(reference, options):
     product = as_ASFProduct(reference, ASFSession())
@@ -67,6 +85,7 @@ def run_test_product_get_stack_options(reference, options):
     product_options = dict(product.get_stack_opts())
     assert product_options == dict(expected_options)
 
+
 def run_test_ASFProduct_download(reference, filename, filetype, additional_urls):
     product = as_ASFProduct(reference, ASFSession())
     product.properties['additionalUrls'] = additional_urls
@@ -75,13 +94,13 @@ def run_test_ASFProduct_download(reference, filename, filetype, additional_urls)
         resp.status_code = 200
         mock_get.return_value = resp
         resp.iter_content = lambda chunk_size: []
-            
-        with patch('builtins.open', unittest.mock.mock_open()) as m:    
-            if filename != None and (
-                (filetype == FileDownloadType.ADDITIONAL_FILES and len(additional_urls) > 1) 
-                or filetype == FileDownloadType.ALL_FILES
+
+        with patch('builtins.open', unittest.mock.mock_open()):
+            if filename is not None and (
+                (filetype == FileDownloadType.ADDITIONAL_FILES and len(additional_urls) > 1)
+                or (filetype == FileDownloadType.ALL_FILES and len(additional_urls) > 0)
             ):
                 with pytest.warns(Warning):
                     product.download('./', filename=filename, fileType=filetype)
             else:
-                product.download('./', filename=filename, fileType=filetype)
\ No newline at end of file
+                product.download('./', filename=filename, fileType=filetype)
